import 'package:flutter/material.dart';
import 'package:furman_now/src/services/events/event.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:furman_now/src/widgets/events/event_modal.dart';
import 'package:intl/intl.dart';

class EventCard extends StatelessWidget {
  const EventCard
    (
      this.event,
      {
        Key? key
      }
    ) : super(key: key);

  final Event event;

  String get eventHour {
    var formatter = DateFormat('hh:mm');
    return formatter.format(event.time);
  }

  String get eventAmPm {
    var formatter = DateFormat('a');
    return formatter.format(event.time);
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        showEventsModal(
          context,
          event,
        );
        // showModalBottomSheet<void>(
        //     context: context,
        //     builder: (BuildContext context) {
        //       return EventModal(event: event);
        //     }
        // );
      },
      child: Container(
        decoration: const BoxDecoration(
          color: Color(0xfff9f9fb),
          borderRadius: BorderRadius.all(Radius.circular(10))
        ),
        child: IntrinsicHeight(
          child: Row(
            children: [
              Container(
                padding: const EdgeInsets.symmetric(horizontal: 15, vertical: 5),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Text(eventHour, style: furmanTextStyle(const TextStyle(fontWeight: FontWeight.w700))),
                    Text(eventAmPm, style: Theme.of(context).textTheme.subtitle2),
                  ],
                ),
              ),
              VerticalDivider(
                width: 2,
                thickness: 2,
                color: Colors.grey[200],
              ),
              Flexible(
                child: Container(
                  padding: const EdgeInsets.symmetric(horizontal: 15, vertical: 10),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(event.title, style: furmanTextStyle(const TextStyle(fontWeight: FontWeight.w600))),
                      const SizedBox(height: 6),
                      RichText(text: TextSpan(
                        style: Theme.of(context).textTheme.subtitle2,
                        children: [
                          WidgetSpan(
                            alignment: PlaceholderAlignment.middle,
                            child: Padding(
                              padding: const EdgeInsets.only(right: 5.0),
                              child: Icon(Icons.place_outlined, size: 20, color: Colors.grey[500])
                            ),
                          ),
                          TextSpan(text: event.location),
                        ],
                      )),
                      const SizedBox(height: 2),
                      RichText(text: TextSpan(
                        style: Theme.of(context).textTheme.subtitle2,
                        children: [
                          WidgetSpan(
                            alignment: PlaceholderAlignment.middle,
                            child: Padding(
                                padding: const EdgeInsets.only(left: 1.0, right: 6.0),
                                child: Icon(Icons.sell_outlined, size: 18, color: Colors.grey[500])
                            ),
                          ),
                          TextSpan(text: event.category),
                        ],
                      )),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}