import 'package:flutter/material.dart';
import 'package:furman_now/src/services/events/event.dart';
import 'package:furman_now/src/store/index.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:provider/provider.dart';

import 'event_card.dart';

class EventsList extends StatefulWidget {
  final DateTimeRange dateRange;

  const EventsList._({
    required this.dateRange,
    Key? key,
  }) : super(key: key);

  factory EventsList({
    DateTimeRange? dateRange,
    Key? key,
  }) {
    if (dateRange == null) {
      final now = DateTime.now();
      final today = DateTime(now.year, now.month, now.day);
      final tonight = DateTime(now.year, now.month, now.day, 23, 59, 59);
      dateRange = DateTimeRange(start: today, end: tonight);
    }
    return EventsList._(
      dateRange: dateRange,
      key: key,
    );
  }

  @override
  State<EventsList> createState() => _EventsListState();
}

class _EventsListState extends State<EventsList> {

  @override
  Widget build(BuildContext context) {
    return Consumer<AppState>(
      builder: (context, state, child) {
        return FutureBuilder<Iterable<Event>>(
          future: state.events,
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              var events = snapshot.data!.where((event) {
                return event.time.isAfter(widget.dateRange.start) &&
                    event.time.isBefore(widget.dateRange.end);
              });
              if (events.isNotEmpty) {
                return Column(
                    children: events.map((event) {
                      return Padding(
                        padding: const EdgeInsets.only(bottom: 15),
                        child: EventCard(event),
                      );
                    }).toList());
              } else {
                return Padding(
                  padding: const EdgeInsets.only(bottom: 15),
                  child: SizedBox(
                    width: double.infinity,
                    height: 50,
                    child: Center(
                      child: Text(
                        "No events today :(",
                        style: furmanTextStyle(TextStyle(
                          color: Colors.grey[600],
                          fontSize: 16,
                          fontWeight: FontWeight.w600,
                        )),
                      ),
                    ),
                  ),
                );
              }
            } else if (snapshot.hasError) {
              return Text(
                '${snapshot.error}', style: const TextStyle(color: Colors.red),);
            }

            // By default, show a loading spinner.
            return const Center(
              child: Padding(
                  padding: EdgeInsets.symmetric(vertical: 25),
                  child: CircularProgressIndicator()
              ),
            );
          },
        );
      }
    );
  }
}